# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="tiff_save_options_data.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class TiffSaveOptionsData(object):
    """Container class for tiff save options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_embedding_post_script_fonts': 'bool',
        'custom_time_zone_info_data': 'TimeZoneInfoData',
        'dml3_d_effects_rendering_mode': 'str',
        'dml_effects_rendering_mode': 'str',
        'dml_rendering_mode': 'str',
        'file_name': 'str',
        'iml_rendering_mode': 'str',
        'update_ambiguous_text_font': 'bool',
        'update_created_time_property': 'bool',
        'update_fields': 'bool',
        'update_last_printed_property': 'bool',
        'update_last_saved_time_property': 'bool',
        'zip_output': 'bool',
        'color_mode': 'str',
        'jpeg_quality': 'int',
        'metafile_rendering_options': 'MetafileRenderingOptionsData',
        'numeral_format': 'str',
        'optimize_output': 'bool',
        'page_count': 'int',
        'page_index': 'int',
        'horizontal_resolution': 'float',
        'image_brightness': 'float',
        'image_color_mode': 'str',
        'image_contrast': 'float',
        'paper_color': 'str',
        'pixel_format': 'str',
        'resolution': 'float',
        'scale': 'float',
        'use_anti_aliasing': 'bool',
        'use_high_quality_rendering': 'bool',
        'vertical_resolution': 'float',
        'image_height': 'int',
        'image_width': 'int',
        'use_gdi_emf_renderer': 'bool',
        'threshold_for_floyd_steinberg_dithering': 'int',
        'tiff_binarization_method': 'str',
        'tiff_compression': 'str',
        'save_format': 'str'
    }

    attribute_map = {
        'allow_embedding_post_script_fonts': 'AllowEmbeddingPostScriptFonts',
        'custom_time_zone_info_data': 'CustomTimeZoneInfoData',
        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
        'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
        'dml_rendering_mode': 'DmlRenderingMode',
        'file_name': 'FileName',
        'iml_rendering_mode': 'ImlRenderingMode',
        'update_ambiguous_text_font': 'UpdateAmbiguousTextFont',
        'update_created_time_property': 'UpdateCreatedTimeProperty',
        'update_fields': 'UpdateFields',
        'update_last_printed_property': 'UpdateLastPrintedProperty',
        'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
        'zip_output': 'ZipOutput',
        'color_mode': 'ColorMode',
        'jpeg_quality': 'JpegQuality',
        'metafile_rendering_options': 'MetafileRenderingOptions',
        'numeral_format': 'NumeralFormat',
        'optimize_output': 'OptimizeOutput',
        'page_count': 'PageCount',
        'page_index': 'PageIndex',
        'horizontal_resolution': 'HorizontalResolution',
        'image_brightness': 'ImageBrightness',
        'image_color_mode': 'ImageColorMode',
        'image_contrast': 'ImageContrast',
        'paper_color': 'PaperColor',
        'pixel_format': 'PixelFormat',
        'resolution': 'Resolution',
        'scale': 'Scale',
        'use_anti_aliasing': 'UseAntiAliasing',
        'use_high_quality_rendering': 'UseHighQualityRendering',
        'vertical_resolution': 'VerticalResolution',
        'image_height': 'ImageHeight',
        'image_width': 'ImageWidth',
        'use_gdi_emf_renderer': 'UseGdiEmfRenderer',
        'threshold_for_floyd_steinberg_dithering': 'ThresholdForFloydSteinbergDithering',
        'tiff_binarization_method': 'TiffBinarizationMethod',
        'tiff_compression': 'TiffCompression',
        'save_format': 'SaveFormat'
    }

    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, iml_rendering_mode=None, update_ambiguous_text_font=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_high_quality_rendering=None, vertical_resolution=None, image_height=None, image_width=None, use_gdi_emf_renderer=None, threshold_for_floyd_steinberg_dithering=None, tiff_binarization_method=None, tiff_compression=None):  # noqa: E501
        """TiffSaveOptionsData - a model defined in Swagger"""  # noqa: E501

        self._allow_embedding_post_script_fonts = None
        self._custom_time_zone_info_data = None
        self._dml3_d_effects_rendering_mode = None
        self._dml_effects_rendering_mode = None
        self._dml_rendering_mode = None
        self._file_name = None
        self._iml_rendering_mode = None
        self._update_ambiguous_text_font = None
        self._update_created_time_property = None
        self._update_fields = None
        self._update_last_printed_property = None
        self._update_last_saved_time_property = None
        self._zip_output = None
        self._color_mode = None
        self._jpeg_quality = None
        self._metafile_rendering_options = None
        self._numeral_format = None
        self._optimize_output = None
        self._page_count = None
        self._page_index = None
        self._horizontal_resolution = None
        self._image_brightness = None
        self._image_color_mode = None
        self._image_contrast = None
        self._paper_color = None
        self._pixel_format = None
        self._resolution = None
        self._scale = None
        self._use_anti_aliasing = None
        self._use_high_quality_rendering = None
        self._vertical_resolution = None
        self._image_height = None
        self._image_width = None
        self._use_gdi_emf_renderer = None
        self._threshold_for_floyd_steinberg_dithering = None
        self._tiff_binarization_method = None
        self._tiff_compression = None
        self._save_format = "tiff"
        self.discriminator = None

        if allow_embedding_post_script_fonts is not None:
            self.allow_embedding_post_script_fonts = allow_embedding_post_script_fonts
        if custom_time_zone_info_data is not None:
            self.custom_time_zone_info_data = custom_time_zone_info_data
        if dml3_d_effects_rendering_mode is not None:
            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
        if dml_effects_rendering_mode is not None:
            self.dml_effects_rendering_mode = dml_effects_rendering_mode
        if dml_rendering_mode is not None:
            self.dml_rendering_mode = dml_rendering_mode
        if file_name is not None:
            self.file_name = file_name
        if iml_rendering_mode is not None:
            self.iml_rendering_mode = iml_rendering_mode
        if update_ambiguous_text_font is not None:
            self.update_ambiguous_text_font = update_ambiguous_text_font
        if update_created_time_property is not None:
            self.update_created_time_property = update_created_time_property
        if update_fields is not None:
            self.update_fields = update_fields
        if update_last_printed_property is not None:
            self.update_last_printed_property = update_last_printed_property
        if update_last_saved_time_property is not None:
            self.update_last_saved_time_property = update_last_saved_time_property
        if zip_output is not None:
            self.zip_output = zip_output
        if color_mode is not None:
            self.color_mode = color_mode
        if jpeg_quality is not None:
            self.jpeg_quality = jpeg_quality
        if metafile_rendering_options is not None:
            self.metafile_rendering_options = metafile_rendering_options
        if numeral_format is not None:
            self.numeral_format = numeral_format
        if optimize_output is not None:
            self.optimize_output = optimize_output
        if page_count is not None:
            self.page_count = page_count
        if page_index is not None:
            self.page_index = page_index
        if horizontal_resolution is not None:
            self.horizontal_resolution = horizontal_resolution
        if image_brightness is not None:
            self.image_brightness = image_brightness
        if image_color_mode is not None:
            self.image_color_mode = image_color_mode
        if image_contrast is not None:
            self.image_contrast = image_contrast
        if paper_color is not None:
            self.paper_color = paper_color
        if pixel_format is not None:
            self.pixel_format = pixel_format
        if resolution is not None:
            self.resolution = resolution
        if scale is not None:
            self.scale = scale
        if use_anti_aliasing is not None:
            self.use_anti_aliasing = use_anti_aliasing
        if use_high_quality_rendering is not None:
            self.use_high_quality_rendering = use_high_quality_rendering
        if vertical_resolution is not None:
            self.vertical_resolution = vertical_resolution
        if image_height is not None:
            self.image_height = image_height
        if image_width is not None:
            self.image_width = image_width
        if use_gdi_emf_renderer is not None:
            self.use_gdi_emf_renderer = use_gdi_emf_renderer
        if threshold_for_floyd_steinberg_dithering is not None:
            self.threshold_for_floyd_steinberg_dithering = threshold_for_floyd_steinberg_dithering
        if tiff_binarization_method is not None:
            self.tiff_binarization_method = tiff_binarization_method
        if tiff_compression is not None:
            self.tiff_compression = tiff_compression

    @property
    def allow_embedding_post_script_fonts(self):
        """Gets the allow_embedding_post_script_fonts of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a boolean value indicating whether to allow embedding fonts with PostScript outlines when embedding TrueType fonts in a document upon it is saved. The default value is false.. Note, Word does not embed PostScript fonts, but can open documents with embedded fonts of this type. This option only works when Aspose.Words.Fonts.FontInfoCollection.EmbedTrueTypeFonts of the Aspose.Words.DocumentBase.FontInfos property is set to true. The default value is false.  # noqa: E501

        :return: The allow_embedding_post_script_fonts of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._allow_embedding_post_script_fonts

    @allow_embedding_post_script_fonts.setter
    def allow_embedding_post_script_fonts(self, allow_embedding_post_script_fonts):
        """Sets the allow_embedding_post_script_fonts of this TiffSaveOptionsData.

        Gets or sets a boolean value indicating whether to allow embedding fonts with PostScript outlines when embedding TrueType fonts in a document upon it is saved. The default value is false.. Note, Word does not embed PostScript fonts, but can open documents with embedded fonts of this type. This option only works when Aspose.Words.Fonts.FontInfoCollection.EmbedTrueTypeFonts of the Aspose.Words.DocumentBase.FontInfos property is set to true. The default value is false.  # noqa: E501

        :param allow_embedding_post_script_fonts: The allow_embedding_post_script_fonts of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._allow_embedding_post_script_fonts = allow_embedding_post_script_fonts

    @property
    def custom_time_zone_info_data(self):
        """Gets the custom_time_zone_info_data of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets CustomTimeZoneInfo.  # noqa: E501

        :return: The custom_time_zone_info_data of this TiffSaveOptionsData.  # noqa: E501
        :rtype: TimeZoneInfoData
        """
        return self._custom_time_zone_info_data

    @custom_time_zone_info_data.setter
    def custom_time_zone_info_data(self, custom_time_zone_info_data):
        """Sets the custom_time_zone_info_data of this TiffSaveOptionsData.

        Gets or sets CustomTimeZoneInfo.  # noqa: E501

        :param custom_time_zone_info_data: The custom_time_zone_info_data of this TiffSaveOptionsData.  # noqa: E501
        :type: TimeZoneInfoData
        """
        self._custom_time_zone_info_data = custom_time_zone_info_data

    @property
    def dml3_d_effects_rendering_mode(self):
        """Gets the dml3_d_effects_rendering_mode of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the value determining how 3D effects are rendered. The default value is Aspose.Words.Saving.Dml3DEffectsRenderingMode.Basic.  # noqa: E501

        :return: The dml3_d_effects_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml3_d_effects_rendering_mode

    @dml3_d_effects_rendering_mode.setter
    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
        """Sets the dml3_d_effects_rendering_mode of this TiffSaveOptionsData.

        Gets or sets the value determining how 3D effects are rendered. The default value is Aspose.Words.Saving.Dml3DEffectsRenderingMode.Basic.  # noqa: E501

        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Basic", "Advanced"]  # noqa: E501
        if not dml3_d_effects_rendering_mode.isdigit():
            if dml3_d_effects_rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(dml3_d_effects_rendering_mode, allowed_values))
            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
        else:
            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]

    @property
    def dml_effects_rendering_mode(self):
        """Gets the dml_effects_rendering_mode of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the value determining how DrawingML effects are rendered. { Simplified | None | Fine }. The default value is Simplified. This property is used when the document is exported to fixed page formats.  # noqa: E501

        :return: The dml_effects_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml_effects_rendering_mode

    @dml_effects_rendering_mode.setter
    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
        """Sets the dml_effects_rendering_mode of this TiffSaveOptionsData.

        Gets or sets the value determining how DrawingML effects are rendered. { Simplified | None | Fine }. The default value is Simplified. This property is used when the document is exported to fixed page formats.  # noqa: E501

        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Simplified", "None", "Fine"]  # noqa: E501
        if not dml_effects_rendering_mode.isdigit():
            if dml_effects_rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `dml_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(dml_effects_rendering_mode, allowed_values))
            self._dml_effects_rendering_mode = dml_effects_rendering_mode
        else:
            self._dml_effects_rendering_mode = allowed_values[int(dml_effects_rendering_mode) if six.PY3 else long(dml_effects_rendering_mode)]

    @property
    def dml_rendering_mode(self):
        """Gets the dml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the option that controls how DrawingML shapes are rendered. { Fallback | DrawingML }. The default value is Fallback. This property is used when the document is exported to fixed page formats.  # noqa: E501

        :return: The dml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml_rendering_mode

    @dml_rendering_mode.setter
    def dml_rendering_mode(self, dml_rendering_mode):
        """Sets the dml_rendering_mode of this TiffSaveOptionsData.

        Gets or sets the option that controls how DrawingML shapes are rendered. { Fallback | DrawingML }. The default value is Fallback. This property is used when the document is exported to fixed page formats.  # noqa: E501

        :param dml_rendering_mode: The dml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Fallback", "DrawingML"]  # noqa: E501
        if not dml_rendering_mode.isdigit():
            if dml_rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `dml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(dml_rendering_mode, allowed_values))
            self._dml_rendering_mode = dml_rendering_mode
        else:
            self._dml_rendering_mode = allowed_values[int(dml_rendering_mode) if six.PY3 else long(dml_rendering_mode)]

    @property
    def file_name(self):
        """Gets the file_name of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the name of destination file.  # noqa: E501

        :return: The file_name of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this TiffSaveOptionsData.

        Gets or sets the name of destination file.  # noqa: E501

        :param file_name: The file_name of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._file_name = file_name

    @property
    def iml_rendering_mode(self):
        """Gets the iml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the value determining how ink (InkML) objects are rendered. The default value is Aspose.Words.Saving.ImlRenderingMode.InkML.  # noqa: E501

        :return: The iml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._iml_rendering_mode

    @iml_rendering_mode.setter
    def iml_rendering_mode(self, iml_rendering_mode):
        """Sets the iml_rendering_mode of this TiffSaveOptionsData.

        Gets or sets the value determining how ink (InkML) objects are rendered. The default value is Aspose.Words.Saving.ImlRenderingMode.InkML.  # noqa: E501

        :param iml_rendering_mode: The iml_rendering_mode of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Fallback", "InkML"]  # noqa: E501
        if not iml_rendering_mode.isdigit():
            if iml_rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `iml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(iml_rendering_mode, allowed_values))
            self._iml_rendering_mode = iml_rendering_mode
        else:
            self._iml_rendering_mode = allowed_values[int(iml_rendering_mode) if six.PY3 else long(iml_rendering_mode)]

    @property
    def update_ambiguous_text_font(self):
        """Gets the update_ambiguous_text_font of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether the font attributes will be changed according to the character code being used.  # noqa: E501

        :return: The update_ambiguous_text_font of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_ambiguous_text_font

    @update_ambiguous_text_font.setter
    def update_ambiguous_text_font(self, update_ambiguous_text_font):
        """Sets the update_ambiguous_text_font of this TiffSaveOptionsData.

        Gets or sets a value indicating whether the font attributes will be changed according to the character code being used.  # noqa: E501

        :param update_ambiguous_text_font: The update_ambiguous_text_font of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_ambiguous_text_font = update_ambiguous_text_font

    @property
    def update_created_time_property(self):
        """Gets the update_created_time_property of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.CreatedTime property is updated before saving. Default value is false.  # noqa: E501

        :return: The update_created_time_property of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_created_time_property

    @update_created_time_property.setter
    def update_created_time_property(self, update_created_time_property):
        """Sets the update_created_time_property of this TiffSaveOptionsData.

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.CreatedTime property is updated before saving. Default value is false.  # noqa: E501

        :param update_created_time_property: The update_created_time_property of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_created_time_property = update_created_time_property

    @property
    def update_fields(self):
        """Gets the update_fields of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether fields should be updated before saving the document to a fixed page format. The default value is true.  # noqa: E501

        :return: The update_fields of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_fields

    @update_fields.setter
    def update_fields(self, update_fields):
        """Sets the update_fields of this TiffSaveOptionsData.

        Gets or sets a value indicating whether fields should be updated before saving the document to a fixed page format. The default value is true.  # noqa: E501

        :param update_fields: The update_fields of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_fields = update_fields

    @property
    def update_last_printed_property(self):
        """Gets the update_last_printed_property of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501

        :return: The update_last_printed_property of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_last_printed_property

    @update_last_printed_property.setter
    def update_last_printed_property(self, update_last_printed_property):
        """Sets the update_last_printed_property of this TiffSaveOptionsData.

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501

        :param update_last_printed_property: The update_last_printed_property of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_last_printed_property = update_last_printed_property

    @property
    def update_last_saved_time_property(self):
        """Gets the update_last_saved_time_property of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving. The default value is false.  # noqa: E501

        :return: The update_last_saved_time_property of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_last_saved_time_property

    @update_last_saved_time_property.setter
    def update_last_saved_time_property(self, update_last_saved_time_property):
        """Sets the update_last_saved_time_property of this TiffSaveOptionsData.

        Gets or sets a value indicating whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving. The default value is false.  # noqa: E501

        :param update_last_saved_time_property: The update_last_saved_time_property of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_last_saved_time_property = update_last_saved_time_property

    @property
    def zip_output(self):
        """Gets the zip_output of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to zip output or not. The default value is false. When set to true, output files will be zipped.  # noqa: E501

        :return: The zip_output of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._zip_output

    @zip_output.setter
    def zip_output(self, zip_output):
        """Sets the zip_output of this TiffSaveOptionsData.

        Gets or sets a value indicating whether to zip output or not. The default value is false. When set to true, output files will be zipped.  # noqa: E501

        :param zip_output: The zip_output of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._zip_output = zip_output

    @property
    def color_mode(self):
        """Gets the color_mode of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the value determining how colors are rendered. { Normal | Grayscale}. The default value is Normal. This property is used when the document is exported to fixed page formats.  # noqa: E501

        :return: The color_mode of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._color_mode

    @color_mode.setter
    def color_mode(self, color_mode):
        """Sets the color_mode of this TiffSaveOptionsData.

        Gets or sets the value determining how colors are rendered. { Normal | Grayscale}. The default value is Normal. This property is used when the document is exported to fixed page formats.  # noqa: E501

        :param color_mode: The color_mode of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Normal", "Grayscale"]  # noqa: E501
        if not color_mode.isdigit():
            if color_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `color_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(color_mode, allowed_values))
            self._color_mode = color_mode
        else:
            self._color_mode = allowed_values[int(color_mode) if six.PY3 else long(color_mode)]

    @property
    def jpeg_quality(self):
        """Gets the jpeg_quality of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the quality of the JPEG images inside PDF document.  # noqa: E501

        :return: The jpeg_quality of this TiffSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._jpeg_quality

    @jpeg_quality.setter
    def jpeg_quality(self, jpeg_quality):
        """Sets the jpeg_quality of this TiffSaveOptionsData.

        Gets or sets the quality of the JPEG images inside PDF document.  # noqa: E501

        :param jpeg_quality: The jpeg_quality of this TiffSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._jpeg_quality = jpeg_quality

    @property
    def metafile_rendering_options(self):
        """Gets the metafile_rendering_options of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the metafile rendering options.  # noqa: E501

        :return: The metafile_rendering_options of this TiffSaveOptionsData.  # noqa: E501
        :rtype: MetafileRenderingOptionsData
        """
        return self._metafile_rendering_options

    @metafile_rendering_options.setter
    def metafile_rendering_options(self, metafile_rendering_options):
        """Sets the metafile_rendering_options of this TiffSaveOptionsData.

        Gets or sets the metafile rendering options.  # noqa: E501

        :param metafile_rendering_options: The metafile_rendering_options of this TiffSaveOptionsData.  # noqa: E501
        :type: MetafileRenderingOptionsData
        """
        self._metafile_rendering_options = metafile_rendering_options

    @property
    def numeral_format(self):
        """Gets the numeral_format of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the symbol set, that is used to represent numbers while rendering to fixed page formats.  # noqa: E501

        :return: The numeral_format of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._numeral_format

    @numeral_format.setter
    def numeral_format(self, numeral_format):
        """Sets the numeral_format of this TiffSaveOptionsData.

        Gets or sets the symbol set, that is used to represent numbers while rendering to fixed page formats.  # noqa: E501

        :param numeral_format: The numeral_format of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["European", "ArabicIndic", "EasternArabicIndic", "Context", "System"]  # noqa: E501
        if not numeral_format.isdigit():
            if numeral_format not in allowed_values:
                raise ValueError(
                    "Invalid value for `numeral_format` ({0}), must be one of {1}"  # noqa: E501
                    .format(numeral_format, allowed_values))
            self._numeral_format = numeral_format
        else:
            self._numeral_format = allowed_values[int(numeral_format) if six.PY3 else long(numeral_format)]

    @property
    def optimize_output(self):
        """Gets the optimize_output of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether it is required to optimize output of XPS. If this flag is set redundant nested canvases and empty canvases are removed, also neighbor glyphs with the same formatting are concatenated. Note: The accuracy of the content display may be affected if this property is set to true.. The default value is false.  # noqa: E501

        :return: The optimize_output of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._optimize_output

    @optimize_output.setter
    def optimize_output(self, optimize_output):
        """Sets the optimize_output of this TiffSaveOptionsData.

        Gets or sets a value indicating whether it is required to optimize output of XPS. If this flag is set redundant nested canvases and empty canvases are removed, also neighbor glyphs with the same formatting are concatenated. Note: The accuracy of the content display may be affected if this property is set to true.. The default value is false.  # noqa: E501

        :param optimize_output: The optimize_output of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._optimize_output = optimize_output

    @property
    def page_count(self):
        """Gets the page_count of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the number of pages to render.  # noqa: E501

        :return: The page_count of this TiffSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """Sets the page_count of this TiffSaveOptionsData.

        Gets or sets the number of pages to render.  # noqa: E501

        :param page_count: The page_count of this TiffSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._page_count = page_count

    @property
    def page_index(self):
        """Gets the page_index of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the 0-based index of the first page to render.  # noqa: E501

        :return: The page_index of this TiffSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this TiffSaveOptionsData.

        Gets or sets the 0-based index of the first page to render.  # noqa: E501

        :param page_index: The page_index of this TiffSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._page_index = page_index

    @property
    def horizontal_resolution(self):
        """Gets the horizontal_resolution of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the horizontal resolution in dots per inch for the generated images. This property has effect only when saving to raster image formats. The default value is 96.  # noqa: E501

        :return: The horizontal_resolution of this TiffSaveOptionsData.  # noqa: E501
        :rtype: float
        """
        return self._horizontal_resolution

    @horizontal_resolution.setter
    def horizontal_resolution(self, horizontal_resolution):
        """Sets the horizontal_resolution of this TiffSaveOptionsData.

        Gets or sets the horizontal resolution in dots per inch for the generated images. This property has effect only when saving to raster image formats. The default value is 96.  # noqa: E501

        :param horizontal_resolution: The horizontal_resolution of this TiffSaveOptionsData.  # noqa: E501
        :type: float
        """
        self._horizontal_resolution = horizontal_resolution

    @property
    def image_brightness(self):
        """Gets the image_brightness of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the brightness level of the image.  # noqa: E501

        :return: The image_brightness of this TiffSaveOptionsData.  # noqa: E501
        :rtype: float
        """
        return self._image_brightness

    @image_brightness.setter
    def image_brightness(self, image_brightness):
        """Sets the image_brightness of this TiffSaveOptionsData.

        Gets or sets the brightness level of the image.  # noqa: E501

        :param image_brightness: The image_brightness of this TiffSaveOptionsData.  # noqa: E501
        :type: float
        """
        self._image_brightness = image_brightness

    @property
    def image_color_mode(self):
        """Gets the image_color_mode of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the color mode of the image.  # noqa: E501

        :return: The image_color_mode of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._image_color_mode

    @image_color_mode.setter
    def image_color_mode(self, image_color_mode):
        """Sets the image_color_mode of this TiffSaveOptionsData.

        Gets or sets the color mode of the image.  # noqa: E501

        :param image_color_mode: The image_color_mode of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Grayscale", "BlackAndWhite"]  # noqa: E501
        if not image_color_mode.isdigit():
            if image_color_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `image_color_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(image_color_mode, allowed_values))
            self._image_color_mode = image_color_mode
        else:
            self._image_color_mode = allowed_values[int(image_color_mode) if six.PY3 else long(image_color_mode)]

    @property
    def image_contrast(self):
        """Gets the image_contrast of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the contrast level of the image.  # noqa: E501

        :return: The image_contrast of this TiffSaveOptionsData.  # noqa: E501
        :rtype: float
        """
        return self._image_contrast

    @image_contrast.setter
    def image_contrast(self, image_contrast):
        """Sets the image_contrast of this TiffSaveOptionsData.

        Gets or sets the contrast level of the image.  # noqa: E501

        :param image_contrast: The image_contrast of this TiffSaveOptionsData.  # noqa: E501
        :type: float
        """
        self._image_contrast = image_contrast

    @property
    def paper_color(self):
        """Gets the paper_color of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the background (paper) color of the image.  # noqa: E501

        :return: The paper_color of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._paper_color

    @paper_color.setter
    def paper_color(self, paper_color):
        """Sets the paper_color of this TiffSaveOptionsData.

        Gets or sets the background (paper) color of the image.  # noqa: E501

        :param paper_color: The paper_color of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._paper_color = paper_color

    @property
    def pixel_format(self):
        """Gets the pixel_format of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the pixel format of the image.  # noqa: E501

        :return: The pixel_format of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._pixel_format

    @pixel_format.setter
    def pixel_format(self, pixel_format):
        """Sets the pixel_format of this TiffSaveOptionsData.

        Gets or sets the pixel format of the image.  # noqa: E501

        :param pixel_format: The pixel_format of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Format16BppRgb555", "Format16BppRgb565", "Format16BppArgb1555", "Format24BppRgb", "Format32BppRgb", "Format32BppArgb", "Format32BppPArgb", "Format48BppRgb", "Format64BppArgb", "Format64BppPArgb", "Format1bppIndexed"]  # noqa: E501
        if not pixel_format.isdigit():
            if pixel_format not in allowed_values:
                raise ValueError(
                    "Invalid value for `pixel_format` ({0}), must be one of {1}"  # noqa: E501
                    .format(pixel_format, allowed_values))
            self._pixel_format = pixel_format
        else:
            self._pixel_format = allowed_values[int(pixel_format) if six.PY3 else long(pixel_format)]

    @property
    def resolution(self):
        """Gets the resolution of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets both horizontal and vertical resolution in dots per inch for the generated images. This property has effect only when saving to raster image formats. The default value is 96.  # noqa: E501

        :return: The resolution of this TiffSaveOptionsData.  # noqa: E501
        :rtype: float
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """Sets the resolution of this TiffSaveOptionsData.

        Gets or sets both horizontal and vertical resolution in dots per inch for the generated images. This property has effect only when saving to raster image formats. The default value is 96.  # noqa: E501

        :param resolution: The resolution of this TiffSaveOptionsData.  # noqa: E501
        :type: float
        """
        self._resolution = resolution

    @property
    def scale(self):
        """Gets the scale of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the zoom factor of the image.  # noqa: E501

        :return: The scale of this TiffSaveOptionsData.  # noqa: E501
        :rtype: float
        """
        return self._scale

    @scale.setter
    def scale(self, scale):
        """Sets the scale of this TiffSaveOptionsData.

        Gets or sets the zoom factor of the image.  # noqa: E501

        :param scale: The scale of this TiffSaveOptionsData.  # noqa: E501
        :type: float
        """
        self._scale = scale

    @property
    def use_anti_aliasing(self):
        """Gets the use_anti_aliasing of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to use anti-aliasing for rendering.  # noqa: E501

        :return: The use_anti_aliasing of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._use_anti_aliasing

    @use_anti_aliasing.setter
    def use_anti_aliasing(self, use_anti_aliasing):
        """Sets the use_anti_aliasing of this TiffSaveOptionsData.

        Gets or sets a value indicating whether to use anti-aliasing for rendering.  # noqa: E501

        :param use_anti_aliasing: The use_anti_aliasing of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._use_anti_aliasing = use_anti_aliasing

    @property
    def use_high_quality_rendering(self):
        """Gets the use_high_quality_rendering of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to use high quality (i.e. slow) rendering algorithms.  # noqa: E501

        :return: The use_high_quality_rendering of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._use_high_quality_rendering

    @use_high_quality_rendering.setter
    def use_high_quality_rendering(self, use_high_quality_rendering):
        """Sets the use_high_quality_rendering of this TiffSaveOptionsData.

        Gets or sets a value indicating whether to use high quality (i.e. slow) rendering algorithms.  # noqa: E501

        :param use_high_quality_rendering: The use_high_quality_rendering of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._use_high_quality_rendering = use_high_quality_rendering

    @property
    def vertical_resolution(self):
        """Gets the vertical_resolution of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the vertical resolution in dots per inch for the generated images. This property has effect only when saving to raster image formats. The default value is 96.  # noqa: E501

        :return: The vertical_resolution of this TiffSaveOptionsData.  # noqa: E501
        :rtype: float
        """
        return self._vertical_resolution

    @vertical_resolution.setter
    def vertical_resolution(self, vertical_resolution):
        """Sets the vertical_resolution of this TiffSaveOptionsData.

        Gets or sets the vertical resolution in dots per inch for the generated images. This property has effect only when saving to raster image formats. The default value is 96.  # noqa: E501

        :param vertical_resolution: The vertical_resolution of this TiffSaveOptionsData.  # noqa: E501
        :type: float
        """
        self._vertical_resolution = vertical_resolution

    @property
    def image_height(self):
        """Gets the image_height of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the height of a generated image in pixels. This property has effect only when saving to raster image formats and used in pair with ImageWidth.  # noqa: E501

        :return: The image_height of this TiffSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._image_height

    @image_height.setter
    def image_height(self, image_height):
        """Sets the image_height of this TiffSaveOptionsData.

        Gets or sets the height of a generated image in pixels. This property has effect only when saving to raster image formats and used in pair with ImageWidth.  # noqa: E501

        :param image_height: The image_height of this TiffSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._image_height = image_height

    @property
    def image_width(self):
        """Gets the image_width of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the width of a generated image in pixels. This property has effect only when saving to raster image formats and used in pair with ImageHeight.  # noqa: E501

        :return: The image_width of this TiffSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._image_width

    @image_width.setter
    def image_width(self, image_width):
        """Sets the image_width of this TiffSaveOptionsData.

        Gets or sets the width of a generated image in pixels. This property has effect only when saving to raster image formats and used in pair with ImageHeight.  # noqa: E501

        :param image_width: The image_width of this TiffSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._image_width = image_width

    @property
    def use_gdi_emf_renderer(self):
        """Gets the use_gdi_emf_renderer of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets a value indicating whether to use GDI+ or Aspose.Words metafile renderer when saving to EMF. If set to true - GDI+ metafile renderer is used. I.e. content is written to GDI+ graphics object and saved to metafile.If set to false - Aspose.Words metafile renderer is used. I.e. content is written directly to the metafile format with Aspose.Words.The default value is true.Has effect only when saving to EMF.  # noqa: E501

        :return: The use_gdi_emf_renderer of this TiffSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._use_gdi_emf_renderer

    @use_gdi_emf_renderer.setter
    def use_gdi_emf_renderer(self, use_gdi_emf_renderer):
        """Sets the use_gdi_emf_renderer of this TiffSaveOptionsData.

        Gets or sets a value indicating whether to use GDI+ or Aspose.Words metafile renderer when saving to EMF. If set to true - GDI+ metafile renderer is used. I.e. content is written to GDI+ graphics object and saved to metafile.If set to false - Aspose.Words metafile renderer is used. I.e. content is written directly to the metafile format with Aspose.Words.The default value is true.Has effect only when saving to EMF.  # noqa: E501

        :param use_gdi_emf_renderer: The use_gdi_emf_renderer of this TiffSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._use_gdi_emf_renderer = use_gdi_emf_renderer

    @property
    def threshold_for_floyd_steinberg_dithering(self):
        """Gets the threshold_for_floyd_steinberg_dithering of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the threshold that determines the value of the binarization error in the Floyd-Steinberg method. when ImageBinarizationMethod is ImageBinarizationMethod.FloydSteinbergDithering. Default value is 128.  # noqa: E501

        :return: The threshold_for_floyd_steinberg_dithering of this TiffSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._threshold_for_floyd_steinberg_dithering

    @threshold_for_floyd_steinberg_dithering.setter
    def threshold_for_floyd_steinberg_dithering(self, threshold_for_floyd_steinberg_dithering):
        """Sets the threshold_for_floyd_steinberg_dithering of this TiffSaveOptionsData.

        Gets or sets the threshold that determines the value of the binarization error in the Floyd-Steinberg method. when ImageBinarizationMethod is ImageBinarizationMethod.FloydSteinbergDithering. Default value is 128.  # noqa: E501

        :param threshold_for_floyd_steinberg_dithering: The threshold_for_floyd_steinberg_dithering of this TiffSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._threshold_for_floyd_steinberg_dithering = threshold_for_floyd_steinberg_dithering

    @property
    def tiff_binarization_method(self):
        """Gets the tiff_binarization_method of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the method used while converting images to 1 bpp format.  # noqa: E501

        :return: The tiff_binarization_method of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._tiff_binarization_method

    @tiff_binarization_method.setter
    def tiff_binarization_method(self, tiff_binarization_method):
        """Sets the tiff_binarization_method of this TiffSaveOptionsData.

        Gets or sets the method used while converting images to 1 bpp format.  # noqa: E501

        :param tiff_binarization_method: The tiff_binarization_method of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Threshold", "FloydSteinbergDithering"]  # noqa: E501
        if not tiff_binarization_method.isdigit():
            if tiff_binarization_method not in allowed_values:
                raise ValueError(
                    "Invalid value for `tiff_binarization_method` ({0}), must be one of {1}"  # noqa: E501
                    .format(tiff_binarization_method, allowed_values))
            self._tiff_binarization_method = tiff_binarization_method
        else:
            self._tiff_binarization_method = allowed_values[int(tiff_binarization_method) if six.PY3 else long(tiff_binarization_method)]

    @property
    def tiff_compression(self):
        """Gets the tiff_compression of this TiffSaveOptionsData.  # noqa: E501

        Gets or sets the type of compression.  # noqa: E501

        :return: The tiff_compression of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._tiff_compression

    @tiff_compression.setter
    def tiff_compression(self, tiff_compression):
        """Sets the tiff_compression of this TiffSaveOptionsData.

        Gets or sets the type of compression.  # noqa: E501

        :param tiff_compression: The tiff_compression of this TiffSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Rle", "Lzw", "Ccitt3", "Ccitt4"]  # noqa: E501
        if not tiff_compression.isdigit():
            if tiff_compression not in allowed_values:
                raise ValueError(
                    "Invalid value for `tiff_compression` ({0}), must be one of {1}"  # noqa: E501
                    .format(tiff_compression, allowed_values))
            self._tiff_compression = tiff_compression
        else:
            self._tiff_compression = allowed_values[int(tiff_compression) if six.PY3 else long(tiff_compression)]

    @property
    def save_format(self):
        """Gets the save_format of this TiffSaveOptionsData.  # noqa: E501

        Gets the format of save.  # noqa: E501

        :return: The save_format of this TiffSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._save_format



    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._file_name is None:
            raise ValueError("Property FileName in TiffSaveOptionsData is required.")  # noqa: E501

        if self._custom_time_zone_info_data is not None:
            self._custom_time_zone_info_data.validate()
















        if self._metafile_rendering_options is not None:
            self._metafile_rendering_options.validate()
























    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TiffSaveOptionsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="page_number.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class PageNumber(object):
    """Class is used for insert page number request building.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alignment': 'str',
        'format': 'str',
        'is_top': 'bool',
        'page_starting_number': 'int',
        'set_page_number_on_first_page': 'bool'
    }

    attribute_map = {
        'alignment': 'Alignment',
        'format': 'Format',
        'is_top': 'IsTop',
        'page_starting_number': 'PageStartingNumber',
        'set_page_number_on_first_page': 'SetPageNumberOnFirstPage'
    }

    def __init__(self, alignment=None, format=None, is_top=None, page_starting_number=None, set_page_number_on_first_page=None):  # noqa: E501
        """PageNumber - a model defined in Swagger"""  # noqa: E501

        self._alignment = None
        self._format = None
        self._is_top = None
        self._page_starting_number = None
        self._set_page_number_on_first_page = None
        self.discriminator = None

        if alignment is not None:
            self.alignment = alignment
        if format is not None:
            self.format = format
        if is_top is not None:
            self.is_top = is_top
        if page_starting_number is not None:
            self.page_starting_number = page_starting_number
        if set_page_number_on_first_page is not None:
            self.set_page_number_on_first_page = set_page_number_on_first_page

    @property
    def alignment(self):
        """Gets the alignment of this PageNumber.  # noqa: E501

        Gets or sets text alignment, possible values are left, right, center or justify.  # noqa: E501

        :return: The alignment of this PageNumber.  # noqa: E501
        :rtype: str
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """Sets the alignment of this PageNumber.

        Gets or sets text alignment, possible values are left, right, center or justify.  # noqa: E501

        :param alignment: The alignment of this PageNumber.  # noqa: E501
        :type: str
        """
        self._alignment = alignment

    @property
    def format(self):
        """Gets the format of this PageNumber.  # noqa: E501

        Gets or sets the page number format, e.g. "{PAGE} of {NUMPAGES}".  # noqa: E501

        :return: The format of this PageNumber.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this PageNumber.

        Gets or sets the page number format, e.g. "{PAGE} of {NUMPAGES}".  # noqa: E501

        :param format: The format of this PageNumber.  # noqa: E501
        :type: str
        """
        self._format = format

    @property
    def is_top(self):
        """Gets the is_top of this PageNumber.  # noqa: E501

        Gets or sets a value indicating whether if true the page number is added at the top of the page, else at the bottom.  # noqa: E501

        :return: The is_top of this PageNumber.  # noqa: E501
        :rtype: bool
        """
        return self._is_top

    @is_top.setter
    def is_top(self, is_top):
        """Sets the is_top of this PageNumber.

        Gets or sets a value indicating whether if true the page number is added at the top of the page, else at the bottom.  # noqa: E501

        :param is_top: The is_top of this PageNumber.  # noqa: E501
        :type: bool
        """
        self._is_top = is_top

    @property
    def page_starting_number(self):
        """Gets the page_starting_number of this PageNumber.  # noqa: E501

        Gets or sets the starting page number of the document.  # noqa: E501

        :return: The page_starting_number of this PageNumber.  # noqa: E501
        :rtype: int
        """
        return self._page_starting_number

    @page_starting_number.setter
    def page_starting_number(self, page_starting_number):
        """Sets the page_starting_number of this PageNumber.

        Gets or sets the starting page number of the document.  # noqa: E501

        :param page_starting_number: The page_starting_number of this PageNumber.  # noqa: E501
        :type: int
        """
        self._page_starting_number = page_starting_number

    @property
    def set_page_number_on_first_page(self):
        """Gets the set_page_number_on_first_page of this PageNumber.  # noqa: E501

        Gets or sets a value indicating whether if true the page number is added on first page too.  # noqa: E501

        :return: The set_page_number_on_first_page of this PageNumber.  # noqa: E501
        :rtype: bool
        """
        return self._set_page_number_on_first_page

    @set_page_number_on_first_page.setter
    def set_page_number_on_first_page(self, set_page_number_on_first_page):
        """Sets the set_page_number_on_first_page of this PageNumber.

        Gets or sets a value indicating whether if true the page number is added on first page too.  # noqa: E501

        :param set_page_number_on_first_page: The set_page_number_on_first_page of this PageNumber.  # noqa: E501
        :type: bool
        """
        self._set_page_number_on_first_page = set_page_number_on_first_page


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._is_top is None:
            raise ValueError("Property IsTop in PageNumber is required.")  # noqa: E501
        if self._set_page_number_on_first_page is None:
            raise ValueError("Property SetPageNumberOnFirstPage in PageNumber is required.")  # noqa: E501

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageNumber):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="file_reference.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json
import uuid

class FileReference(object):
    swagger_types = {
        'source': 'str',
        'reference': 'str',
        'password': 'str',
        'encryptedPassword': 'str'
    }

    attribute_map = {
        'source': 'Source',
        'reference': 'Reference',
        'password': 'Password',
        'encryptedPassword': 'EncryptedPassword'
    }

    def __init__(self, source, reference, content, password):  # noqa: E501
        self._source = source
        self._reference = reference
        self._content = content
        self._password = password
        self._encryptedPassword = None

    @staticmethod
    def fromRemoteFilePath(remoteFilePath, password = None):
        return FileReference('Storage', remoteFilePath, None, password)

    @staticmethod
    def fromLocalFileContent(localFileContent, password = None):
        return FileReference('Request', str(uuid.uuid4()), localFileContent, password)

    @property
    def source(self):
        return self._source

    @property
    def reference(self):
        return self._reference

    @property
    def content(self):
        return self._content

    @property
    def password(self):
        return self._password

    @property
    def encryptedPassword(self):
        return self._encryptedPassword

    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""
        if self._source == 'Request':
            filesContentResult.append(self)

    def encryptPassword(self, encryptor):
        if self._password is not None:
            self._encryptedPassword = encryptor.encrypt(self._password)
            self._password = None

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="storage_file.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class StorageFile(object):
    """File or folder information.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_folder': 'bool',
        'modified_date': 'datetime',
        'name': 'str',
        'path': 'str',
        'size': 'int'
    }

    attribute_map = {
        'is_folder': 'IsFolder',
        'modified_date': 'ModifiedDate',
        'name': 'Name',
        'path': 'Path',
        'size': 'Size'
    }

    def __init__(self, is_folder=None, modified_date=None, name=None, path=None, size=None):  # noqa: E501
        """StorageFile - a model defined in Swagger"""  # noqa: E501

        self._is_folder = None
        self._modified_date = None
        self._name = None
        self._path = None
        self._size = None
        self.discriminator = None

        if is_folder is not None:
            self.is_folder = is_folder
        if modified_date is not None:
            self.modified_date = modified_date
        if name is not None:
            self.name = name
        if path is not None:
            self.path = path
        if size is not None:
            self.size = size

    @property
    def is_folder(self):
        """Gets the is_folder of this StorageFile.  # noqa: E501

        True if it is a folder.  # noqa: E501

        :return: The is_folder of this StorageFile.  # noqa: E501
        :rtype: bool
        """
        return self._is_folder

    @is_folder.setter
    def is_folder(self, is_folder):
        """Sets the is_folder of this StorageFile.

        True if it is a folder.  # noqa: E501

        :param is_folder: The is_folder of this StorageFile.  # noqa: E501
        :type: bool
        """
        self._is_folder = is_folder

    @property
    def modified_date(self):
        """Gets the modified_date of this StorageFile.  # noqa: E501

        File or folder last modified DateTime.  # noqa: E501

        :return: The modified_date of this StorageFile.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """Sets the modified_date of this StorageFile.

        File or folder last modified DateTime.  # noqa: E501

        :param modified_date: The modified_date of this StorageFile.  # noqa: E501
        :type: datetime
        """
        self._modified_date = modified_date

    @property
    def name(self):
        """Gets the name of this StorageFile.  # noqa: E501

        File or folder name.  # noqa: E501

        :return: The name of this StorageFile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StorageFile.

        File or folder name.  # noqa: E501

        :param name: The name of this StorageFile.  # noqa: E501
        :type: str
        """
        self._name = name

    @property
    def path(self):
        """Gets the path of this StorageFile.  # noqa: E501

        File or folder path.  # noqa: E501

        :return: The path of this StorageFile.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this StorageFile.

        File or folder path.  # noqa: E501

        :param path: The path of this StorageFile.  # noqa: E501
        :type: str
        """
        self._path = path

    @property
    def size(self):
        """Gets the size of this StorageFile.  # noqa: E501

        File or folder size.  # noqa: E501

        :return: The size of this StorageFile.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this StorageFile.

        File or folder size.  # noqa: E501

        :param size: The size of this StorageFile.  # noqa: E501
        :type: int
        """
        self._size = size


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._is_folder is None:
            raise ValueError("Property IsFolder in StorageFile is required.")  # noqa: E501
        if self._size is None:
            raise ValueError("Property Size in StorageFile is required.")  # noqa: E501

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageFile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="footnote_update.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class FootnoteUpdate(object):
    """Footnote for update.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'position': 'Position',
        'footnote_type': 'str',
        'reference_mark': 'str',
        'text': 'str'
    }

    attribute_map = {
        'position': 'Position',
        'footnote_type': 'FootnoteType',
        'reference_mark': 'ReferenceMark',
        'text': 'Text'
    }

    def __init__(self, position=None, footnote_type=None, reference_mark=None, text=None):  # noqa: E501
        """FootnoteUpdate - a model defined in Swagger"""  # noqa: E501

        self._position = None
        self._footnote_type = None
        self._reference_mark = None
        self._text = None
        self.discriminator = None

        if position is not None:
            self.position = position
        if footnote_type is not None:
            self.footnote_type = footnote_type
        if reference_mark is not None:
            self.reference_mark = reference_mark
        if text is not None:
            self.text = text

    @property
    def position(self):
        """Gets the position of this FootnoteUpdate.  # noqa: E501

        Gets or sets the link to range start node.  # noqa: E501

        :return: The position of this FootnoteUpdate.  # noqa: E501
        :rtype: Position
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this FootnoteUpdate.

        Gets or sets the link to range start node.  # noqa: E501

        :param position: The position of this FootnoteUpdate.  # noqa: E501
        :type: Position
        """
        self._position = position

    @property
    def footnote_type(self):
        """Gets the footnote_type of this FootnoteUpdate.  # noqa: E501

        Gets or sets the option, that specifies whether this is a footnote or endnote.  # noqa: E501

        :return: The footnote_type of this FootnoteUpdate.  # noqa: E501
        :rtype: str
        """
        return self._footnote_type

    @footnote_type.setter
    def footnote_type(self, footnote_type):
        """Sets the footnote_type of this FootnoteUpdate.

        Gets or sets the option, that specifies whether this is a footnote or endnote.  # noqa: E501

        :param footnote_type: The footnote_type of this FootnoteUpdate.  # noqa: E501
        :type: str
        """
        allowed_values = ["Footnote", "Endnote"]  # noqa: E501
        if not footnote_type.isdigit():
            if footnote_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `footnote_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(footnote_type, allowed_values))
            self._footnote_type = footnote_type
        else:
            self._footnote_type = allowed_values[int(footnote_type) if six.PY3 else long(footnote_type)]

    @property
    def reference_mark(self):
        """Gets the reference_mark of this FootnoteUpdate.  # noqa: E501

        Gets or sets the custom reference mark to be used for this footnote. Default value is Empty, meaning auto-numbered footnotes are used. RTF-format can only store 1 symbol as custom reference mark, so upon export only the first symbol will be written others will be discard.  # noqa: E501

        :return: The reference_mark of this FootnoteUpdate.  # noqa: E501
        :rtype: str
        """
        return self._reference_mark

    @reference_mark.setter
    def reference_mark(self, reference_mark):
        """Sets the reference_mark of this FootnoteUpdate.

        Gets or sets the custom reference mark to be used for this footnote. Default value is Empty, meaning auto-numbered footnotes are used. RTF-format can only store 1 symbol as custom reference mark, so upon export only the first symbol will be written others will be discard.  # noqa: E501

        :param reference_mark: The reference_mark of this FootnoteUpdate.  # noqa: E501
        :type: str
        """
        self._reference_mark = reference_mark

    @property
    def text(self):
        """Gets the text of this FootnoteUpdate.  # noqa: E501

        Gets or sets text of the footnote. This method allows to quickly set text of a footnote from a string. The string can contain paragraph breaks, this will create paragraphs of text in the footnote accordingly.  # noqa: E501

        :return: The text of this FootnoteUpdate.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this FootnoteUpdate.

        Gets or sets text of the footnote. This method allows to quickly set text of a footnote from a string. The string can contain paragraph breaks, this will create paragraphs of text in the footnote accordingly.  # noqa: E501

        :param text: The text of this FootnoteUpdate.  # noqa: E501
        :type: str
        """
        self._text = text


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

        if self._position is not None:
            self._position.validate()





    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FootnoteUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="style_update.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class StyleUpdate(object):
    """Represents a single document style properties to update.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'next_paragraph_style_name': 'str',
        'base_style_name': 'str',
        'is_quick_style': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'next_paragraph_style_name': 'NextParagraphStyleName',
        'base_style_name': 'BaseStyleName',
        'is_quick_style': 'IsQuickStyle',
        'name': 'Name'
    }

    def __init__(self, next_paragraph_style_name=None, base_style_name=None, is_quick_style=None, name=None):  # noqa: E501
        """StyleUpdate - a model defined in Swagger"""  # noqa: E501

        self._next_paragraph_style_name = None
        self._base_style_name = None
        self._is_quick_style = None
        self._name = None
        self.discriminator = None

        if next_paragraph_style_name is not None:
            self.next_paragraph_style_name = next_paragraph_style_name
        if base_style_name is not None:
            self.base_style_name = base_style_name
        if is_quick_style is not None:
            self.is_quick_style = is_quick_style
        if name is not None:
            self.name = name

    @property
    def next_paragraph_style_name(self):
        """Gets the next_paragraph_style_name of this StyleUpdate.  # noqa: E501

        Gets or sets the name of the style to be applied automatically to a new paragraph inserted after a paragraph formatted with the specified style. This property is not used by Aspose.Words. The next paragraph style will only be applied automatically when you edit the document in MS Word.  # noqa: E501

        :return: The next_paragraph_style_name of this StyleUpdate.  # noqa: E501
        :rtype: str
        """
        return self._next_paragraph_style_name

    @next_paragraph_style_name.setter
    def next_paragraph_style_name(self, next_paragraph_style_name):
        """Sets the next_paragraph_style_name of this StyleUpdate.

        Gets or sets the name of the style to be applied automatically to a new paragraph inserted after a paragraph formatted with the specified style. This property is not used by Aspose.Words. The next paragraph style will only be applied automatically when you edit the document in MS Word.  # noqa: E501

        :param next_paragraph_style_name: The next_paragraph_style_name of this StyleUpdate.  # noqa: E501
        :type: str
        """
        self._next_paragraph_style_name = next_paragraph_style_name

    @property
    def base_style_name(self):
        """Gets the base_style_name of this StyleUpdate.  # noqa: E501

        Gets or sets the name of the style this style is based on. This will be an empty string if the style is not based on any other style and it can be set to an empty string.  # noqa: E501

        :return: The base_style_name of this StyleUpdate.  # noqa: E501
        :rtype: str
        """
        return self._base_style_name

    @base_style_name.setter
    def base_style_name(self, base_style_name):
        """Sets the base_style_name of this StyleUpdate.

        Gets or sets the name of the style this style is based on. This will be an empty string if the style is not based on any other style and it can be set to an empty string.  # noqa: E501

        :param base_style_name: The base_style_name of this StyleUpdate.  # noqa: E501
        :type: str
        """
        self._base_style_name = base_style_name

    @property
    def is_quick_style(self):
        """Gets the is_quick_style of this StyleUpdate.  # noqa: E501

        Gets or sets a value indicating whether this style is shown in the Quick Style gallery inside MS Word UI.  # noqa: E501

        :return: The is_quick_style of this StyleUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._is_quick_style

    @is_quick_style.setter
    def is_quick_style(self, is_quick_style):
        """Sets the is_quick_style of this StyleUpdate.

        Gets or sets a value indicating whether this style is shown in the Quick Style gallery inside MS Word UI.  # noqa: E501

        :param is_quick_style: The is_quick_style of this StyleUpdate.  # noqa: E501
        :type: bool
        """
        self._is_quick_style = is_quick_style

    @property
    def name(self):
        """Gets the name of this StyleUpdate.  # noqa: E501

        Gets or sets the name of the style. Can not be empty string. If there already is a style with such name in the collection, than this style will override it. All affected nodes will reference new style.  # noqa: E501

        :return: The name of this StyleUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StyleUpdate.

        Gets or sets the name of the style. Can not be empty string. If there already is a style with such name in the collection, than this style will override it. All affected nodes will reference new style.  # noqa: E501

        :param name: The name of this StyleUpdate.  # noqa: E501
        :type: str
        """
        self._name = name


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StyleUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="xml_data_load_options.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class XmlDataLoadOptions(object):
    """Represents options for XML data loading. To learn more, visit the LINQ Reporting Engine documentation article. An instance of this class can be passed into constructors of XmlDataSource.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'always_generate_root_object': 'bool'
    }

    attribute_map = {
        'always_generate_root_object': 'AlwaysGenerateRootObject'
    }

    def __init__(self, always_generate_root_object=None):  # noqa: E501
        """XmlDataLoadOptions - a model defined in Swagger"""  # noqa: E501

        self._always_generate_root_object = None
        self.discriminator = None

        if always_generate_root_object is not None:
            self.always_generate_root_object = always_generate_root_object

    @property
    def always_generate_root_object(self):
        """Gets the always_generate_root_object of this XmlDataLoadOptions.  # noqa: E501

        Gets or sets a flag indicating whether a generated data source will always contain an object for an XML root element. If an XML root element has no attributes and all its child elements have same names, such an object is not created by default. The default value is false.  # noqa: E501

        :return: The always_generate_root_object of this XmlDataLoadOptions.  # noqa: E501
        :rtype: bool
        """
        return self._always_generate_root_object

    @always_generate_root_object.setter
    def always_generate_root_object(self, always_generate_root_object):
        """Sets the always_generate_root_object of this XmlDataLoadOptions.

        Gets or sets a flag indicating whether a generated data source will always contain an object for an XML root element. If an XML root element has no attributes and all its child elements have same names, such an object is not created by default. The default value is false.  # noqa: E501

        :param always_generate_root_object: The always_generate_root_object of this XmlDataLoadOptions.  # noqa: E501
        :type: bool
        """
        self._always_generate_root_object = always_generate_root_object


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._always_generate_root_object is None:
            raise ValueError("Property AlwaysGenerateRootObject in XmlDataLoadOptions is required.")  # noqa: E501

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, XmlDataLoadOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="field_options.py">
#   Copyright (c) 2025 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class FieldOptions(object):
    """DTO for field options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_user': 'UserInformation',
        'custom_toc_style_separator': 'str',
        'default_document_author': 'str',
        'field_index_format': 'str',
        'field_update_culture_name': 'str',
        'field_update_culture_source': 'str',
        'file_name': 'str',
        'is_bidi_text_supported_on_update': 'bool',
        'legacy_number_format': 'bool',
        'pre_process_culture_name': 'str',
        'template_name': 'str',
        'use_invariant_culture_number_format': 'bool',
        'built_in_templates_paths': 'list[str]'
    }

    attribute_map = {
        'current_user': 'CurrentUser',
        'custom_toc_style_separator': 'CustomTocStyleSeparator',
        'default_document_author': 'DefaultDocumentAuthor',
        'field_index_format': 'FieldIndexFormat',
        'field_update_culture_name': 'FieldUpdateCultureName',
        'field_update_culture_source': 'FieldUpdateCultureSource',
        'file_name': 'FileName',
        'is_bidi_text_supported_on_update': 'IsBidiTextSupportedOnUpdate',
        'legacy_number_format': 'LegacyNumberFormat',
        'pre_process_culture_name': 'PreProcessCultureName',
        'template_name': 'TemplateName',
        'use_invariant_culture_number_format': 'UseInvariantCultureNumberFormat',
        'built_in_templates_paths': 'BuiltInTemplatesPaths'
    }

    def __init__(self, current_user=None, custom_toc_style_separator=None, default_document_author=None, field_index_format=None, field_update_culture_name=None, field_update_culture_source=None, file_name=None, is_bidi_text_supported_on_update=None, legacy_number_format=None, pre_process_culture_name=None, template_name=None, use_invariant_culture_number_format=None, built_in_templates_paths=None):  # noqa: E501
        """FieldOptions - a model defined in Swagger"""  # noqa: E501

        self._current_user = None
        self._custom_toc_style_separator = None
        self._default_document_author = None
        self._field_index_format = None
        self._field_update_culture_name = None
        self._field_update_culture_source = None
        self._file_name = None
        self._is_bidi_text_supported_on_update = None
        self._legacy_number_format = None
        self._pre_process_culture_name = None
        self._template_name = None
        self._use_invariant_culture_number_format = None
        self._built_in_templates_paths = None
        self.discriminator = None

        if current_user is not None:
            self.current_user = current_user
        if custom_toc_style_separator is not None:
            self.custom_toc_style_separator = custom_toc_style_separator
        if default_document_author is not None:
            self.default_document_author = default_document_author
        if field_index_format is not None:
            self.field_index_format = field_index_format
        if field_update_culture_name is not None:
            self.field_update_culture_name = field_update_culture_name
        if field_update_culture_source is not None:
            self.field_update_culture_source = field_update_culture_source
        if file_name is not None:
            self.file_name = file_name
        if is_bidi_text_supported_on_update is not None:
            self.is_bidi_text_supported_on_update = is_bidi_text_supported_on_update
        if legacy_number_format is not None:
            self.legacy_number_format = legacy_number_format
        if pre_process_culture_name is not None:
            self.pre_process_culture_name = pre_process_culture_name
        if template_name is not None:
            self.template_name = template_name
        if use_invariant_culture_number_format is not None:
            self.use_invariant_culture_number_format = use_invariant_culture_number_format
        if built_in_templates_paths is not None:
            self.built_in_templates_paths = built_in_templates_paths

    @property
    def current_user(self):
        """Gets the current_user of this FieldOptions.  # noqa: E501

        Gets or sets Curren tUser.  # noqa: E501

        :return: The current_user of this FieldOptions.  # noqa: E501
        :rtype: UserInformation
        """
        return self._current_user

    @current_user.setter
    def current_user(self, current_user):
        """Sets the current_user of this FieldOptions.

        Gets or sets Curren tUser.  # noqa: E501

        :param current_user: The current_user of this FieldOptions.  # noqa: E501
        :type: UserInformation
        """
        self._current_user = current_user

    @property
    def custom_toc_style_separator(self):
        """Gets the custom_toc_style_separator of this FieldOptions.  # noqa: E501

        Gets or sets Custom Toc Style Separator.  # noqa: E501

        :return: The custom_toc_style_separator of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._custom_toc_style_separator

    @custom_toc_style_separator.setter
    def custom_toc_style_separator(self, custom_toc_style_separator):
        """Sets the custom_toc_style_separator of this FieldOptions.

        Gets or sets Custom Toc Style Separator.  # noqa: E501

        :param custom_toc_style_separator: The custom_toc_style_separator of this FieldOptions.  # noqa: E501
        :type: str
        """
        self._custom_toc_style_separator = custom_toc_style_separator

    @property
    def default_document_author(self):
        """Gets the default_document_author of this FieldOptions.  # noqa: E501

        Gets or sets Default Document Author.  # noqa: E501

        :return: The default_document_author of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._default_document_author

    @default_document_author.setter
    def default_document_author(self, default_document_author):
        """Sets the default_document_author of this FieldOptions.

        Gets or sets Default Document Author.  # noqa: E501

        :param default_document_author: The default_document_author of this FieldOptions.  # noqa: E501
        :type: str
        """
        self._default_document_author = default_document_author

    @property
    def field_index_format(self):
        """Gets the field_index_format of this FieldOptions.  # noqa: E501

        Gets or sets Field Index Format.  # noqa: E501

        :return: The field_index_format of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._field_index_format

    @field_index_format.setter
    def field_index_format(self, field_index_format):
        """Sets the field_index_format of this FieldOptions.

        Gets or sets Field Index Format.  # noqa: E501

        :param field_index_format: The field_index_format of this FieldOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["Template", "Classic", "Fancy", "Modern", "Bulleted", "Formal", "Simple"]  # noqa: E501
        if not field_index_format.isdigit():
            if field_index_format not in allowed_values:
                raise ValueError(
                    "Invalid value for `field_index_format` ({0}), must be one of {1}"  # noqa: E501
                    .format(field_index_format, allowed_values))
            self._field_index_format = field_index_format
        else:
            self._field_index_format = allowed_values[int(field_index_format) if six.PY3 else long(field_index_format)]

    @property
    def field_update_culture_name(self):
        """Gets the field_update_culture_name of this FieldOptions.  # noqa: E501

        Gets or sets Field Update Culture Name. It is used for all fields if FieldUpdateCultureSource is FieldCode.  # noqa: E501

        :return: The field_update_culture_name of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._field_update_culture_name

    @field_update_culture_name.setter
    def field_update_culture_name(self, field_update_culture_name):
        """Sets the field_update_culture_name of this FieldOptions.

        Gets or sets Field Update Culture Name. It is used for all fields if FieldUpdateCultureSource is FieldCode.  # noqa: E501

        :param field_update_culture_name: The field_update_culture_name of this FieldOptions.  # noqa: E501
        :type: str
        """
        self._field_update_culture_name = field_update_culture_name

    @property
    def field_update_culture_source(self):
        """Gets the field_update_culture_source of this FieldOptions.  # noqa: E501

        Gets or sets Field Update Culture Source.  # noqa: E501

        :return: The field_update_culture_source of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._field_update_culture_source

    @field_update_culture_source.setter
    def field_update_culture_source(self, field_update_culture_source):
        """Sets the field_update_culture_source of this FieldOptions.

        Gets or sets Field Update Culture Source.  # noqa: E501

        :param field_update_culture_source: The field_update_culture_source of this FieldOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["CurrentThread", "FieldCode"]  # noqa: E501
        if not field_update_culture_source.isdigit():
            if field_update_culture_source not in allowed_values:
                raise ValueError(
                    "Invalid value for `field_update_culture_source` ({0}), must be one of {1}"  # noqa: E501
                    .format(field_update_culture_source, allowed_values))
            self._field_update_culture_source = field_update_culture_source
        else:
            self._field_update_culture_source = allowed_values[int(field_update_culture_source) if six.PY3 else long(field_update_culture_source)]

    @property
    def file_name(self):
        """Gets the file_name of this FieldOptions.  # noqa: E501

        Gets or sets File Name.  # noqa: E501

        :return: The file_name of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this FieldOptions.

        Gets or sets File Name.  # noqa: E501

        :param file_name: The file_name of this FieldOptions.  # noqa: E501
        :type: str
        """
        self._file_name = file_name

    @property
    def is_bidi_text_supported_on_update(self):
        """Gets the is_bidi_text_supported_on_update of this FieldOptions.  # noqa: E501

        Gets or sets if Bidi Text Supported OnUpdate.  # noqa: E501

        :return: The is_bidi_text_supported_on_update of this FieldOptions.  # noqa: E501
        :rtype: bool
        """
        return self._is_bidi_text_supported_on_update

    @is_bidi_text_supported_on_update.setter
    def is_bidi_text_supported_on_update(self, is_bidi_text_supported_on_update):
        """Sets the is_bidi_text_supported_on_update of this FieldOptions.

        Gets or sets if Bidi Text Supported OnUpdate.  # noqa: E501

        :param is_bidi_text_supported_on_update: The is_bidi_text_supported_on_update of this FieldOptions.  # noqa: E501
        :type: bool
        """
        self._is_bidi_text_supported_on_update = is_bidi_text_supported_on_update

    @property
    def legacy_number_format(self):
        """Gets the legacy_number_format of this FieldOptions.  # noqa: E501

        Gets or sets if Legacy Number Format.  # noqa: E501

        :return: The legacy_number_format of this FieldOptions.  # noqa: E501
        :rtype: bool
        """
        return self._legacy_number_format

    @legacy_number_format.setter
    def legacy_number_format(self, legacy_number_format):
        """Sets the legacy_number_format of this FieldOptions.

        Gets or sets if Legacy Number Format.  # noqa: E501

        :param legacy_number_format: The legacy_number_format of this FieldOptions.  # noqa: E501
        :type: bool
        """
        self._legacy_number_format = legacy_number_format

    @property
    def pre_process_culture_name(self):
        """Gets the pre_process_culture_name of this FieldOptions.  # noqa: E501

        Gets or sets PreProcess Culture Name. It is a culture code for DOC fields.  # noqa: E501

        :return: The pre_process_culture_name of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._pre_process_culture_name

    @pre_process_culture_name.setter
    def pre_process_culture_name(self, pre_process_culture_name):
        """Sets the pre_process_culture_name of this FieldOptions.

        Gets or sets PreProcess Culture Name. It is a culture code for DOC fields.  # noqa: E501

        :param pre_process_culture_name: The pre_process_culture_name of this FieldOptions.  # noqa: E501
        :type: str
        """
        self._pre_process_culture_name = pre_process_culture_name

    @property
    def template_name(self):
        """Gets the template_name of this FieldOptions.  # noqa: E501

        Gets or sets Template Name.  # noqa: E501

        :return: The template_name of this FieldOptions.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this FieldOptions.

        Gets or sets Template Name.  # noqa: E501

        :param template_name: The template_name of this FieldOptions.  # noqa: E501
        :type: str
        """
        self._template_name = template_name

    @property
    def use_invariant_culture_number_format(self):
        """Gets the use_invariant_culture_number_format of this FieldOptions.  # noqa: E501

        Gets or sets if Use Invariant Culture Number Format.  # noqa: E501

        :return: The use_invariant_culture_number_format of this FieldOptions.  # noqa: E501
        :rtype: bool
        """
        return self._use_invariant_culture_number_format

    @use_invariant_culture_number_format.setter
    def use_invariant_culture_number_format(self, use_invariant_culture_number_format):
        """Sets the use_invariant_culture_number_format of this FieldOptions.

        Gets or sets if Use Invariant Culture Number Format.  # noqa: E501

        :param use_invariant_culture_number_format: The use_invariant_culture_number_format of this FieldOptions.  # noqa: E501
        :type: bool
        """
        self._use_invariant_culture_number_format = use_invariant_culture_number_format

    @property
    def built_in_templates_paths(self):
        """Gets the built_in_templates_paths of this FieldOptions.  # noqa: E501

        Gets or sets BuiltIn Templates Paths.  # noqa: E501

        :return: The built_in_templates_paths of this FieldOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._built_in_templates_paths

    @built_in_templates_paths.setter
    def built_in_templates_paths(self, built_in_templates_paths):
        """Sets the built_in_templates_paths of this FieldOptions.

        Gets or sets BuiltIn Templates Paths.  # noqa: E501

        :param built_in_templates_paths: The built_in_templates_paths of this FieldOptions.  # noqa: E501
        :type: list[str]
        """
        self._built_in_templates_paths = built_in_templates_paths


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

        if self._current_user is not None:
            self._current_user.validate()














    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other